Class DocumentIdReference<B>

java.lang.Object
io.micronaut.serde.reference.PropertyReference<B,Object>
io.micronaut.serde.support.reference.DocumentIdReference<B>
Type Parameters:
B - The bean type

@Internal public final class DocumentIdReference<B> extends PropertyReference<B,Object>
A bean registered under, or looked up by, its document-scoped identifier. Pushed through PropertyReferenceManager.pushManagedRef(PropertyReference) to register the bean for the current document and passed to Deserializer.DecoderContext.resolveReference(PropertyReference) to look it up; the reference name is the identifier.
Since:
3.2
  • Constructor Details

    • DocumentIdReference

      public DocumentIdReference(String id, @Nullable io.micronaut.core.beans.BeanIntrospection<B> introspection, io.micronaut.core.type.Argument<Object> idArgument, @Nullable B bean)
      Creates a document identifier reference.
      Parameters:
      id - The identifier
      introspection - The bean introspection, null for a lookup
      idArgument - The identifier property
      bean - The bean, null for a lookup