Interface PendingDocumentIdReference.DocumentIdConsumer

Enclosing class:
PendingDocumentIdReference
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface PendingDocumentIdReference.DocumentIdConsumer
Receives the bean once its identifier is registered.
Since:
3.2
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    accept(Object bean)
    Receives the resolved bean.
  • Method Details

    • accept

      void accept(Object bean) throws IOException
      Receives the resolved bean.
      Parameters:
      bean - The bean
      Throws:
      IOException - If the reference cannot be set