Delete temporary files
Arguments
- base_dir
Character string with the path to the temporary directory.
- minutes_keep
Numeric. Age in minutes from which on folders are deleted; more recent folders are kept.
- list_files
Logical, whether all files should be listed.
- delete
Logical, weather all files should be deleted.
- verbose
Logical, whether messages are sent to the console.